Skip to main contentCrate fecund_font_flounder
Source - clusterer
- Clustering algorithms for colors.
- color
Color trait and its implementations for various color- field
- Two dimensional array of things with cells having size so two fields with differents cell size
can be overlayed miningfully
- fonts
- Responsible for creating and editing a font
- preset_picture
- Collection of premade converters for images to terminal strings.
- printer
- functions for turning a part of a Field (FieldView) into a Chixol
- terminal_control
- Terminal specific functions